import { IClassicComm } from "@jupyter-widgets/base";
import { JupyterMessage } from "@nteract/messaging";
/**
 * Class used by widgets to communicate with the backend
 */
export declare class WidgetComm implements IClassicComm {
    comm_id: string;
    target_name: string;
    target_module: string;
    kernel: any;
    /**
     *
     * @param comm_id uuid
     * @param target_name comm handler
     * @param target_module used to select a module that is responsible for handling the target_name
     * @param kernel A reference to the
     */
    constructor(comm_id: string, target_name: string, target_module: string, kernel: any);
    /**
     * Opens a sibling comm in the backend
     * @param  data
     * @param  callbacks
     * @param  metadata
     * @return msg id
     */
    open(data: any, callbacks: any, metadata?: any, buffers?: ArrayBuffer[] | ArrayBufferView[]): string;
    /**
     * Sends a message to the sibling comm in the backend
     * @param  data
     * @param  callbacks
     * @param  metadata
     * @param  buffers
     * @return message id
     */
    send(data: any, callbacks: any, metadata?: any, buffers?: ArrayBuffer[] | ArrayBufferView[]): string;
    /**
     * Closes the sibling comm in the backend
     * @param  data
     * @param  callbacks
     * @param  metadata
     * @return msg id
     */
    close(data?: any, callbacks?: any, metadata?: any, buffers?: ArrayBuffer[] | ArrayBufferView[]): string;
    /**
     * Register a message handler
     * @param  callback, which is given a message
     */
    on_msg(callback: (x: any) => void): void;
    /**
     * Register a handler for when the comm is closed by the backend
     * @param  callback, which is given a message
     */
    on_close(callback: (x: any) => void): void;
    /**
     * Convert the buffer array that iPyWidgets use into the single
     * Uint8Array that nteract expects for creating messages
     * @param buffers iPyWidgets buffer format
     * @return nteract buffer format
     */
    flattenBufferArrays(buffers?: ArrayBuffer[] | ArrayBufferView[]): Uint8Array | undefined;
    /**
     * Subscribes to message replies and routes them to the right callbacks
     * provided by widgets
     * @param message
     * @param callbacks
     */
    hookupReplyCallbacks(message: JupyterMessage<any, any>, callbacks: any): void;
}
/**
 * Requests the state of a model from the kernel. This method is static because it
 * needs to be called before a Comm object is made
 * @param kernel
 * @param comm_id
 */
export declare function request_state(kernel: any, comm_id: string): Promise<any>;
